@@ -1,5 +1,3 @@
-from plum import Dispatcher, Self
-
 from .. import _dispatch
 from ..function import (
     Function,
@@ -23,8 +21,6 @@ class DerivativeFunction(WrappedFunction):
             take the derivative of. Set to `None` to not take a derivative.
     """
 
-    _dispatch = Dispatcher(in_class=Self)
-
     def __init__(self, e, *derivs):
         WrappedFunction.__init__(self, e)
         self.derivs = derivs
@@ -36,21 +32,21 @@ class DerivativeFunction(WrappedFunction):
             derivs = self.derivs
         return "d{} {}".format(derivs, e)
 
-    @_dispatch(Self)
-    def __eq__(self, other):
+    @_dispatch
+    def __eq__(self, other: "DerivativeFunction"):
         return self[0] == other[0] and identical(self.derivs, other.derivs)
 
 
-@_dispatch(Function, [object])
-def diff(a, *derivs):
+@_dispatch
+def diff(a: Function, *derivs):
     return new(a, DerivativeFunction)(a, *derivs)
 
 
-@_dispatch(ZeroFunction, [object], precedence=proven())
-def diff(a, *derivs):
+@_dispatch(precedence=proven())
+def diff(a: ZeroFunction, *derivs):
     return a
 
 
-@_dispatch(OneFunction, [object], precedence=proven())
-def diff(a, *derivs):
+@_dispatch(precedence=proven())
+def diff(a: OneFunction, *derivs):
     return new(a, ZeroFunction)()
