@@ -1,9 +1,10 @@
+from typing import Union
+
 import lab as B
-from plum import Dispatcher, Self
 
 from .. import _dispatch
-from ..function import Function, OneFunction, ZeroFunction, WrappedFunction
 from ..algebra import proven, new
+from ..function import Function, OneFunction, ZeroFunction, WrappedFunction
 from ..util import squeeze, identical
 
 __all__ = ["SelectedFunction"]
@@ -17,8 +18,6 @@ class SelectedFunction(WrappedFunction):
         *dims (tensor): Dimensions to select.
     """
 
-    _dispatch = Dispatcher(in_class=Self)
-
     def __init__(self, e, *dims):
         WrappedFunction.__init__(self, e)
         self.dims = tuple(None if x is None else _to_list(x) for x in dims)
@@ -26,8 +25,8 @@ class SelectedFunction(WrappedFunction):
     def render_wrap(self, e, formatter):
         return "{} : {}".format(e, squeeze(tuple(self.dims)))
 
-    @_dispatch(Self)
-    def __eq__(self, other):
+    @_dispatch
+    def __eq__(self, other: "SelectedFunction"):
         return self[0] == other[0] and identical(self.dims, other.dims)
 
 
@@ -40,11 +39,11 @@ def _to_list(x):
         raise ValueError(f'Could not convert "{x}" to a list.')
 
 
-@_dispatch(Function, [object])
-def select(a, *dims):
+@_dispatch
+def select(a: Function, *dims):
     return new(a, SelectedFunction)(a, *dims)
 
 
-@_dispatch({ZeroFunction, OneFunction}, [object], precedence=proven())
-def select(a, *dims):
+@_dispatch(precedence=proven())
+def select(a: Union[ZeroFunction, OneFunction], *dims):
     return a
