@@ -1,10 +1,9 @@
 import operator
-
-from plum import Dispatcher, Self
+from typing import Union
 
 from .. import _dispatch
-from ..function import Function, OneFunction, ZeroFunction, WrappedFunction
 from ..algebra import proven, new
+from ..function import Function, OneFunction, ZeroFunction, WrappedFunction
 from ..util import to_tensor, squeeze, identical, broadcast
 
 __all__ = ["StretchedFunction"]
@@ -18,8 +17,6 @@ class StretchedFunction(WrappedFunction):
         *stretches (tensor): Extent of stretches.
     """
 
-    _dispatch = Dispatcher(in_class=Self)
-
     def __init__(self, e, *stretches):
         WrappedFunction.__init__(self, e)
         self.stretches = tuple(to_tensor(x) for x in stretches)
@@ -28,21 +25,21 @@ class StretchedFunction(WrappedFunction):
         stretches = tuple(formatter(s) for s in self.stretches)
         return "{} > {}".format(e, squeeze(stretches))
 
-    @_dispatch(Self)
-    def __eq__(self, other):
+    @_dispatch
+    def __eq__(self, other: "StretchedFunction"):
         return self[0] == other[0] and identical(self.stretches, other.stretches)
 
 
-@_dispatch(Function, [object])
-def stretch(a, *stretches):
+@_dispatch
+def stretch(a: Function, *stretches):
     return new(a, StretchedFunction)(a, *stretches)
 
 
-@_dispatch({ZeroFunction, OneFunction}, [object], precedence=proven())
-def stretch(a, *stretches):
+@_dispatch(precedence=proven())
+def stretch(a: Union[ZeroFunction, OneFunction], *stretches):
     return a
 
 
-@_dispatch(StretchedFunction, [object], precedence=proven())
-def stretch(a, *stretches):
+@_dispatch(precedence=proven())
+def stretch(a: StretchedFunction, *stretches):
     return stretch(a[0], *broadcast(operator.mul, a.stretches, stretches))
