@@ -1,8 +1,8 @@
-from plum import Dispatcher, Self
+from typing import Union
 
 from .. import _dispatch
-from ..function import Function, OneFunction, ZeroFunction, WrappedFunction
 from ..algebra import proven, new
+from ..function import Function, OneFunction, ZeroFunction, WrappedFunction
 from ..util import identical
 
 __all__ = ["InputTransformedFunction"]
@@ -17,8 +17,6 @@ class InputTransformedFunction(WrappedFunction):
             do a transformation.
     """
 
-    _dispatch = Dispatcher(in_class=Self)
-
     def __init__(self, e, *fs):
         WrappedFunction.__init__(self, e)
         self.fs = fs
@@ -34,16 +32,16 @@ class InputTransformedFunction(WrappedFunction):
             fs = "({})".format(", ".join(name(f) for f in self.fs))
         return "{} transform {}".format(e, fs)
 
-    @_dispatch(Self)
-    def __eq__(self, other):
+    @_dispatch
+    def __eq__(self, other: "InputTransformedFunction"):
         return self[0] == other[0] and identical(self.fs, other.fs)
 
 
-@_dispatch(Function, [object])
-def transform(a, *fs):
+@_dispatch
+def transform(a: Function, *fs):
     return new(a, InputTransformedFunction)(a, *fs)
 
 
-@_dispatch({ZeroFunction, OneFunction}, [object], precedence=proven())
-def transform(a, *fs):
+@_dispatch(precedence=proven())
+def transform(a: Union[ZeroFunction, OneFunction], *fs):
     return a
